==> toshset_1.71.orig.tar.gz: toshset-1.71/toshibaIDs.cc <==

#include "toshibaIDs.hh"

static ToshibaID idList[] = {
  {0xfc00  ,"Satellite 2140CDS"},
  {0xfc01  ,"Satellite 2670/2675/2715XDVD"},
  {0xfc02  ,"Satellite Pro 4290"},
  {0xfc04  ,"Portege 3440CT"},
  {0xfc08  ,"Satellite 2100CDS/CDT"},
  {0xfc09  ,"Satellite 2610CDT, 2650XDVD"},
  {0xfc0a  ,"Portage 7140CT"},
  {0xfc0b  ,"Satellite Pro 4200"},
  {0xfc0c  ,"Tecra 8100x"},
  {0xfc0f  ,"Satellite 2060CDS/CDT"},
  {0xfc10  ,"Satellite 2550/2590"},
  {0xfc11  ,"Portage 3110CT"},
  {0xfc12  ,"Portage 3300CT"},
  {0xfc13  ,"Portege 7020CT"},
  {0xfc15  ,"Satellite 4030/4030X/4050/4060/4070/4080/4090/4100X CDS/CDT"},
  {0xfc17  ,"Satellite 2545X/2520/2540 CDS/CDT"},
  {0xfc18  ,"Satellite 4000/4010 XCDT"},
  {0xfc19  ,"Satellite 4000/4010/4020 CDS/CDT"},
  {0xfc1a  ,"Tecra 8000x"},
  {0xfc1c  ,"Satellite 2510CDS/CDT"},
  {0xfc1d  ,"Portage 3020x"},
  {0xfc1f  ,"Portage 7000CT/7010CT"},
  {0xfc39  ,"T2200SX"},
  {0xfc40  ,"T4500C"},
  {0xfc41  ,"T4500"},
  {0xfc45  ,"T4400SX/SXC"},
  {0xfc51  ,"Satellite S2210CDT"},
  {0xfc52  ,"2770 dvd"},
  {0xfc53  ,"Portege 7200/7220"},
  {0xfc54  ,"Libretto 50CT, Satellite 2805-S401"},
  {0xfc56  ,"Portege 3480CT"},
  {0xfc57  ,"Satellite 2250XCDS"},
  {0xfc5a  ,"Satellite Pro 4600"},
  {0xfc5d  ,"Satellite 2805-s402"},
  {0xfc5f  ,"T3300SL"},
  {0xfc61  ,"Tecra 8200 PT8200U"},
  {0xfc63  ,"Tecra 9000"},
  {0xfc64  ,"Satellite 1800-S253"},
  {0xfc67  ,"Portege 4000"},
  {0xfc68  ,"Satellite PS287A, 2805-s503"},
  {0xfc69  ,"T1900C"},
  {0xfc6a  ,"T1900"},
  {0xfc6c  ,"satellite 5005-s504"},
  {0xfc6d  ,"T1850C"},
  {0xfc6e  ,"T1850"},
  {0xfc6f  ,"T1800"},
  {0xfc70  ,"Libretto L2"},
  {0xfc71  ,"Satellite Pro 6000"},
  {0xfc72  ,"Satellite 1805-S207/S274, 1800-712/814"},
  {0xfc73  ,"Portege 2000"},
  {0xfc77  ,"Satellite 5005-S507"},
  {0xfc78  ,"Tecra 9100"},
  {0xfc79  ,"Satellite TE2000"},
  {0xfc7a  ,"Satellite 5100-201,5105-S607"},
  {0xfc7b  ,"Portege 4010"},
  {0xfc7d  ,"satellite pro 6100"},
  {0xfc7e  ,"T4600C"},
  {0xfc7f  ,"T4600"},
  {0xfc8a  ,"T6600C"},
  {0xfc8b  ,"Libretto L5"},
  {0xfc8c  ,"TE2100"},
  {0xfc86  ,"Satellite TE2100"},
  {0xfc91  ,"T2400CT"},
  {0xfc97  ,"T4800CT"},
  {0xfc98  ,"T1910"},
  {0xfc99  ,"T4700CS"},
  {0xfc9b  ,"T4700CT"},
  {0xfc9d  ,"T1950"},
  {0xfc9e  ,"T3400/T3400CT"},
  {0xfcb2  ,"Libretto 30CT"},
  {0xfca1  ,"Satellite 2400-103, 1405-s171"},
  {0xfca3  ,"Satellite 1405-S151, 1400-103, 1400-503"},
  {0xfca5  ,"Satellite 5100-503, 5105-S901"},
  {0xfca7  ,"DynaBook SS S5"},
  {0xfca8  ,"Satellite 5200-*, 5205-*"},
  {0xfca9  ,"Satellite 2410-*, 1410-604, 1415-S173"},
  {0xfcac  ,"Portege 3505"},
  {0xfcb0  ,"Satellite Pro M10, M15-S405"},
  {0xfcba  ,"T2150"},
  {0xfcb5  ,"T2130CT"},
  {0xfcbe  ,"T4850CT"},
  {0xfcc0  ,"Satellite Pro 420x"},
  {0xfcc1  ,"Satellite 100x"},
  {0xfcc3  ,"Tecra 710x/720x"},
  {0xfcc6  ,"Satellite Pro 410x"},
  {0xfcca  ,"Satellite Pro 400x"},
  {0xfccb  ,"Portage 610CT"},
  {0xfccc  ,"Tecra 700x"},
  {0xfccf  ,"T4900CT"},
  {0xfcd0  ,"Satellite 300x"},
  {0xfcd1  ,"Tecra 750CDT"},
  {0xfcd2  ,"Vision Connect -- what is this???"},
  {0xfcd3  ,"Tecra 730XCDT"},
  {0xfcd4  ,"Tecra 510x"},
  {0xfcd5  ,"Satellite 200x"},
  {0xfcd6  ,"Libretto 50CT"},
  {0xfcd7  ,"Satellite Pro 430x"},
  {0xfcd8  ,"Tecra 740x"},
  {0xfcd9  ,"Portage 660CDT"},
  {0xfcda  ,"Tecra 730x/730X"},
  {0xfcdb  ,"Portage 620CT"},
  {0xfcdc  ,"Portage 650CT"},
  {0xfcdd  ,"Satellite 110x"},
  {0xfcdf  ,"Tecra 500x"},
  {0xfce0  ,"Tecra 780DVD"},
  {0xfce2  ,"Satellite 300x"},
  {0xfce3  ,"Satellite 310x"},
  {0xfce4  ,"Satellite Pro 490x"},
  {0xfce5  ,"Libretto 100CT"},
  {0xfce6  ,"Libretto 70CT"},
  {0xfce7  ,"Tecra 540x/550x"},
  {0xfce8  ,"Satellite Pro 470x/480x"},
  {0xfce9  ,"Tecra 750DVD"},
  {0xfcea  ,"Libretto 60"},
  {0xfceb  ,"Libretto 50CT"},
  {0xfcec  ,"Satellite 320x/330x, Satellite 2500CDS"},
  {0xfced  ,"Tecra 520x/530x"},
  {0xfcef  ,"Satellite 220x, Satellite Pro 440x/460x"},
  {0xfcf1  ,"Tecra M1"},
  {0xfcf3  ,"Satellite 2450"},
  {0xfcf5  ,"Satellite 5200-903"},
  {0xfcf6  ,"R100"},
  {0xfcf7  ,"Satellite A10-213"},
  {0xfcf8  ,"Satellite A10, A20, A25-S207"},
  {0xfcff  ,"Portege M100/M300 Tecra M2/A2/A3"},
  {0       ,"" } 
};


extern "C" int
checkToshibaID(int id)
{
 for (int i=0 ; idList[i].id ; i++)
   if ( id == idList[i].id )
     return 1;
 return 0;
} /* checkToshibaID */


extern "C" const char*
toshibaModelName(int id)
{
 for (int i=0 ; idList[i].id ; i++)
   if ( id == idList[i].id )
     return idList[i].name;
 return "unknown";
} /* toshibaModelName */

==> toshset_1.72.orig.tar.gz: toshset-1.72/toshibaIDs.cc <==

#include "toshibaIDs.hh"

static ToshibaID idList[] = {
  {0xfc00  ,"Satellite 2140CDS"},
  {0xfc01  ,"Satellite 2670/2675/2715XDVD"},
  {0xfc02  ,"Satellite Pro 4290"},
  {0xfc04  ,"Portege 3440CT"},
  {0xfc08  ,"Satellite 2100CDS/CDT"},
  {0xfc09  ,"Satellite 2610CDT, 2650XDVD"},
  {0xfc0a  ,"Portage 7140CT"},
  {0xfc0b  ,"Satellite Pro 4200"},
  {0xfc0c  ,"Tecra 8100x"},
  {0xfc0f  ,"Satellite 2060CDS/CDT"},
  {0xfc10  ,"Satellite 2550/2590"},
  {0xfc11  ,"Portage 3110CT"},
  {0xfc12  ,"Portage 3300CT"},
  {0xfc13  ,"Portege 7020CT"},
  {0xfc15  ,"Satellite 4030/4030X/4050/4060/4070/4080/4090/4100X CDS/CDT"},
  {0xfc17  ,"Satellite 2545X/2520/2540 CDS/CDT"},
  {0xfc18  ,"Satellite 4000/4010 XCDT"},
  {0xfc19  ,"Satellite 4000/4010/4020 CDS/CDT"},
  {0xfc1a  ,"Tecra 8000x"},
  {0xfc1c  ,"Satellite 2510CDS/CDT"},
  {0xfc1d  ,"Portage 3020x"},
  {0xfc1f  ,"Portage 7000CT/7010CT"},
  {0xfc39  ,"T2200SX"},
  {0xfc40  ,"T4500C"},
  {0xfc41  ,"T4500"},
  {0xfc45  ,"T4400SX/SXC"},
  {0xfc51  ,"Satellite S2210CDT"},
  {0xfc52  ,"2770 dvd"},
  {0xfc53  ,"Portege 7200/7220"},
  {0xfc54  ,"Libretto 50CT, Satellite 2805-S401"},
  {0xfc56  ,"Portege 3480CT"},
  {0xfc57  ,"Satellite 2250XCDS"},
  {0xfc5a  ,"Satellite Pro 4600"},
  {0xfc5b  ,"Satellite T2115CS"},
  {0xfc5d  ,"Satellite 2805-s402"},
  {0xfc5f  ,"T3300SL"},
  {0xfc61  ,"Tecra 8200 PT8200U"},
  {0xfc63  ,"Tecra 9000"},
  {0xfc64  ,"Satellite 1800-S253"},
  {0xfc67  ,"Portege 4000"},
  {0xfc68  ,"Satellite PS287A, 2805-s503"},
  {0xfc69  ,"T1900C"},
  {0xfc6a  ,"T1900"},
  {0xfc6c  ,"satellite 5005-s504"},
  {0xfc6d  ,"T1850C"},
  {0xfc6e  ,"T1850"},
  {0xfc6f  ,"T1800"},
  {0xfc70  ,"Libretto L2"},
  {0xfc71  ,"Satellite Pro 6000"},
  {0xfc72  ,"Satellite 1805-S207/S274, 1800-712/814"},
  {0xfc73  ,"Portege 2000"},
  {0xfc77  ,"Satellite 5005-S507"},
  {0xfc78  ,"Tecra 9100"},
  {0xfc79  ,"Satellite TE2000"},
  {0xfc7a  ,"Satellite 5100-201,5105-S607"},
  {0xfc7b  ,"Portege 4010"},
  {0xfc7d  ,"satellite pro 6100"},
  {0xfc7e  ,"T4600C"},
  {0xfc7f  ,"T4600"},
  {0xfc8a  ,"T6600C"},
  {0xfc8b  ,"Libretto L5"},
  {0xfc8c  ,"TE2100"},
  {0xfc86  ,"Satellite TE2100"},
  {0xfc91  ,"T2400CT"},
  {0xfc97  ,"T4800CT"},
  {0xfc98  ,"T1910"},
  {0xfc99  ,"T4700CS"},
  {0xfc9b  ,"T4700CT"},
  {0xfc9d  ,"T1950"},
  {0xfc9e  ,"T3400/T3400CT"},
  {0xfcb2  ,"Libretto 30CT"},
  {0xfca1  ,"Satellite 2400-103, 1405-s171"},
  {0xfca2  ,"Dynabook SS 2000M"},
  {0xfca3  ,"Satellite 1405-S151, 1400-103, 1400-503"},
  {0xfca5  ,"Satellite 5100-503, 5105-S901"},
  {0xfca6  ,"Portege 2010"},
  {0xfca7  ,"DynaBook SS S5"},
  {0xfca8  ,"Satellite 5200-*, 5205-*"},
  {0xfca9  ,"Satellite 2410-*, 1410-604, 1415-S173"},
  {0xfcac  ,"Portege 3505"},
  {0xfcb0  ,"Satellite Pro M10, M15-S405"},
  {0xfcba  ,"T2150"},
  {0xfcb5  ,"T2130CT"},
  {0xfcbe  ,"T4850CT"},
  {0xfcc0  ,"Satellite Pro 420x"},
  {0xfcc1  ,"Satellite 100x"},
  {0xfcc3  ,"Tecra 710x/720x"},
  {0xfcc6  ,"Satellite Pro 410x"},
  {0xfcca  ,"Satellite Pro 400x"},
  {0xfccb  ,"Portage 610CT"},
  {0xfccc  ,"Tecra 700x"},
  {0xfccf  ,"T4900CT"},
  {0xfcd0  ,"Satellite 300x"},
  {0xfcd1  ,"Tecra 750CDT"},
  {0xfcd2  ,"Vision Connect -- what is this???"},
  {0xfcd3  ,"Tecra 730XCDT"},
  {0xfcd4  ,"Tecra 510x"},
  {0xfcd5  ,"Satellite 200x"},
  {0xfcd6  ,"Libretto 50CT"},
  {0xfcd7  ,"Satellite Pro 430x"},
  {0xfcd8  ,"Tecra 740x"},
  {0xfcd9  ,"Portage 660CDT"},
  {0xfcda  ,"Tecra 730x/730X"},
  {0xfcdb  ,"Portage 620CT"},
  {0xfcdc  ,"Portage 650CT"},
  {0xfcdd  ,"Satellite 110x"},
  {0xfcdf  ,"Tecra 500x"},
  {0xfce0  ,"Tecra 780DVD"},
  {0xfce2  ,"Satellite 300x"},
  {0xfce3  ,"Satellite 310x"},
  {0xfce4  ,"Satellite Pro 490x"},
  {0xfce5  ,"Libretto 100CT"},
  {0xfce6  ,"Libretto 70CT"},
  {0xfce7  ,"Tecra 540x/550x"},
  {0xfce8  ,"Satellite Pro 470x/480x"},
  {0xfce9  ,"Tecra 750DVD"},
  {0xfcea  ,"Libretto 60"},
  {0xfceb  ,"Libretto 50CT"},
  {0xfcec  ,"Satellite 320x/330x, Satellite 2500CDS"},
  {0xfced  ,"Tecra 520x/530x"},
  {0xfcef  ,"Satellite 220x, Satellite Pro 440x/460x"},
  {0xfcf1  ,"Tecra M1"},
  {0xfcf3  ,"Satellite 2450"},
  {0xfcf5  ,"Satellite 5200-903"},
  {0xfcf6  ,"R100"},
  {0xfcf7  ,"Satellite A10-213"},
  {0xfcf8  ,"Satellite A10, A20, A25-S207"},
  {0xfcff  ,"Portege M100/M300 Tecra M2/A2/A3/M4"},
  {0       ,"" } 
};


extern "C" int
checkToshibaID(int id)
{
 for (int i=0 ; idList[i].id ; i++)
   if ( id == idList[i].id )
     return 1;
 return 0;
} /* checkToshibaID */


extern "C" const char*
toshibaModelName(int id)
{
 for (int i=0 ; idList[i].id ; i++)
   if ( id == idList[i].id )
     return idList[i].name;
 return "unknown";
} /* toshibaModelName */
